<?php



/**

 * Start output buffering

 *

 * This is needed for redirecting to post when a new post has made

 *

 * @since 0.8

 */

function wpuf_buffer_start() {

    ob_start();

}



add_action( 'init', 'wpuf_buffer_start' );



/**

 * Format the post status for user dashboard

 *

 * @param string $status

 * @since version 0.1

 * @author Tareq Hasan

 */

function wpuf_show_post_status( $status ) {



    if ( $status == 'publish' ) {



        $title = __( 'Live', 'wpuf' );

        $fontcolor = '#33CC33';

    } else if ( $status == 'draft' ) {



        $title = __( 'Offline', 'wpuf' );

        $fontcolor = '#bbbbbb';

    } else if ( $status == 'pending' ) {



        $title = __( 'Awaiting Approval', 'wpuf' );

        $fontcolor = '#C00202';

    } else if ( $status == 'future' ) {

        $title = __( 'Scheduled', 'wpuf' );

        $fontcolor = '#bbbbbb';



    } else if ( $status == 'private' ) {

        $title = __( 'Private', 'wpuf' );

        $fontcolor = '#bbbbbb';

    }



    $show_status = '<span style="color:' . $fontcolor . ';">' . $title . '</span>';

    echo apply_filters( 'wpuf_show_post_status', $show_status, $status );

}



/**

 * Format the post status for user dashboard

 *

 * @param string $status

 * @since version 0.1

 * @author Tareq Hasan

 */

function wpuf_admin_post_status( $status ) {



    if ( $status == 'publish' ) {



        $title = __( 'Published', 'wpuf' );

        $fontcolor = '#009200';

    } else if ( $status == 'draft' || $status == 'private' ) {



        $title = __( 'Draft', 'wpuf' );

        $fontcolor = '#bbbbbb';

    } else if ( $status == 'pending' ) {



        $title = __( 'Pending', 'wpuf' );

        $fontcolor = '#C00202';

    } else if ( $status == 'future' ) {

        $title = __( 'Scheduled', 'wpuf' );

        $fontcolor = '#bbbbbb';

    }



    echo '<span style="color:' . $fontcolor . ';">' . $title . '</span>';

}



/**

 * Upload the files to the post as attachemnt

 *

 * @param <type> $post_id

 */

function wpuf_upload_attachment( $post_id ) {

    if ( !isset( $_FILES['wpuf_post_attachments'] ) ) {

        return false;

    }



    $fields = (int) wpuf_get_option( 'attachment_num' );



    for ($i = 0; $i < $fields; $i++) {

        $file_name = basename( $_FILES['wpuf_post_attachments']['name'][$i] );



        if ( $file_name ) {

            if ( $file_name ) {

                $upload = array(

                    'name' => $_FILES['wpuf_post_attachments']['name'][$i],

                    'type' => $_FILES['wpuf_post_attachments']['type'][$i],

                    'tmp_name' => $_FILES['wpuf_post_attachments']['tmp_name'][$i],

                    'error' => $_FILES['wpuf_post_attachments']['error'][$i],

                    'size' => $_FILES['wpuf_post_attachments']['size'][$i]

                );



                wpuf_upload_file( $upload );

            }//file exists

        }// end for

    }

}



/**

 * Get the attachments of a post

 *

 * @param int $post_id

 * @return array attachment list

 */

function wpfu_get_attachments( $post_id ) {

    $att_list = array();



    $args = array(

        'post_type' => 'attachment',

        'numberposts' => -1,

        'post_status' => null,

        'post_parent' => $post_id,

        'order' => 'ASC',

        'orderby' => 'menu_order'

    );



    $attachments = get_posts( $args );



    foreach ($attachments as $attachment) {

        $att_list[] = array(

            'id' => $attachment->ID,

            'title' => $attachment->post_title,

            'url' => wp_get_attachment_url( $attachment->ID ),

            'mime' => $attachment->post_mime_type

        );

    }



    return $att_list;

}



/**

 * Remove the mdedia upload tabs from subscribers

 *

 * @package WP User Frontend

 * @author Tareq Hasan

 */

function wpuf_unset_media_tab( $list ) {

    if ( !current_user_can( 'edit_posts' ) ) {

        unset( $list['library'] );

        unset( $list['gallery'] );

    }



    return $list;

}



add_filter( 'media_upload_tabs', 'wpuf_unset_media_tab' );



/**

 * Get the registered post types

 *

 * @return array

 */

function wpuf_get_post_types() {

    $post_types = get_post_types();



    foreach ($post_types as $key => $val) {

        if ( $val == 'attachment' || $val == 'revision' || $val == 'nav_menu_item' ) {

            unset( $post_types[$key] );

        }

    }



    return $post_types;

}



/**

 * Get lists of users from database

 *

 * @return array

 */

function wpuf_list_users() {

    global $wpdb;



    $users = $wpdb->get_results( "SELECT ID, user_login from $wpdb->users" );



    $list = array();



    if ( $users ) {

        foreach ($users as $user) {

            $list[$user->ID] = $user->user_login;

        }

    }



    return $list;

}



/**

 * Retrieve or display list of posts as a dropdown (select list).

 *

 * @return string HTML content, if not displaying.

 */

function wpuf_get_pages( $post_type = 'page' ) {

    global $wpdb;



    $array = array();

    $pages = get_pages( array('post_type' => $post_type) );

    if ( $pages ) {

        foreach ($pages as $page) {

            $array[$page->ID] = $page->post_title;

        }

    }



    return $array;

}



/**

 * Edit post link for frontend

 *

 * @since 0.7

 * @param string $url url of the original post edit link

 * @param int $post_id

 * @return string url of the current edit post page

 */

function wpuf_edit_post_link( $url, $post_id ) {

    if ( is_admin() ) {

        return $url;

    }



    $override = wpuf_get_option( 'override_editlink', 'wpuf_general', 'yes' );

    if ( $override == 'yes' ) {

        $url = '';

        if ( wpuf_get_option( 'enable_post_edit', 'wpuf_dashboard', 'yes' ) == 'yes' ) {

            $edit_page = (int) wpuf_get_option( 'edit_page_id', 'wpuf_general' );

            $url = get_permalink( $edit_page );



            $url = wp_nonce_url( $url . '?pid=' . $post_id, 'wpuf_edit' );

        }

    }



    return $url;

}



add_filter( 'get_edit_post_link', 'wpuf_edit_post_link', 10, 2 );



/**

 * Create HTML dropdown list of Categories.

 *

 * @package WordPress

 * @since 2.1.0

 * @uses Walker

 */

class WPUF_Walker_Category_Multi extends Walker {



    /**

     * @see Walker::$tree_type

     * @var string

     */

    var $tree_type = 'category';



    /**

     * @see Walker::$db_fields

     * @var array

     */

    var $db_fields = array('parent' => 'parent', 'id' => 'term_id');



    /**

     * @see Walker::start_el()

     *

     * @param string $output Passed by reference. Used to append additional content.

     * @param object $category Category data object.

     * @param int $depth Depth of category. Used for padding.

     * @param array $args Uses 'selected' and 'show_count' keys, if they exist.

     */

    function start_el( &$output, $category, $depth, $args, $id = 0 ) {

        $pad = str_repeat( '&nbsp;', $depth * 3 );



        $cat_name = apply_filters( 'list_cats', $category->name, $category );

        $output .= "\t<option class=\"level-$depth\" value=\"" . $category->term_id . "\"";

        if ( in_array( $category->term_id, $args['selected'] ) )

            $output .= ' selected="selected"';

        $output .= '>';

        $output .= $pad . $cat_name;

        if ( $args['show_count'] )

            $output .= '&nbsp;&nbsp;(' . $category->count . ')';

        $output .= "</option>\n";

    }



}



/**

 * Category checklist walker

 *

 * @since 0.8

 */

class WPUF_Walker_Category_Checklist extends Walker {



    var $tree_type = 'category';

    var $db_fields = array('parent' => 'parent', 'id' => 'term_id'); //TODO: decouple this



    function start_lvl( &$output, $depth, $args ) {

        $indent = str_repeat( "\t", $depth );

        $output .= "$indent<ul class='children'>\n";

    }



    function end_lvl( &$output, $depth, $args ) {

        $indent = str_repeat( "\t", $depth );

        $output .= "$indent</ul>\n";

    }



    function start_el( &$output, $category, $depth, $args ) {

        extract( $args );

        if ( empty( $taxonomy ) )

            $taxonomy = 'category';



        if ( $taxonomy == 'category' )

            $name = 'category';

        else

            $name = $taxonomy;



        $output .= "\n<li id='{$taxonomy}-{$category->term_id}'>" . '<label class="selectit"><input value="' . $category->term_id . '" type="checkbox" name="' . $name . '[]" id="in-' . $taxonomy . '-' . $category->term_id . '"' . checked( in_array( $category->term_id, $selected_cats ), true, false ) . disabled( empty( $args['disabled'] ), false, false ) . ' /> ' . esc_html( apply_filters( 'the_category', $category->name ) ) . '</label>';

    }



    function end_el( &$output, $category, $depth, $args ) {

        $output .= "</li>\n";

    }



}



/**

 * Displays checklist of a taxonomy

 *

 * @since 0.8

 * @param int $post_id

 * @param array $selected_cats

 */

function wpuf_category_checklist( $post_id = 0, $selected_cats = false, $tax = 'category', $exclude = false, $attr = array() ) {

    require_once ABSPATH . '/wp-admin/includes/template.php';



    $walker = new WPUF_Walker_Category_Checklist();



    $args = array(

        'taxonomy' => $tax,

    );



    if ( $post_id ) {

        $args['selected_cats'] = wp_get_object_terms( $post_id, $tax, array('fields' => 'ids') );

    } elseif ( $selected_cats ) {

        $args['selected_cats'] = $selected_cats;

    } else {

        $args['selected_cats'] = array();

    }



    $categories = (array) get_terms( $tax, array(

        'get' => 'all',

        'hide_empty' => false,

        'exclude' => $exclude,

        'orderby' => isset( $attr['orderby'] ) ? $attr['orderby'] : 'name',

        'order' => isset( $attr['order'] ) ? $attr['order'] : 'ASC',

    ) );



    echo '<ul class="wpuf-category-checklist">';

    echo call_user_func_array( array(&$walker, 'walk'), array($categories, 0, $args) );

    echo '</ul>';

}



/**

 * Get all the image sizes

 *

 * @return array image sizes

 */

function wpuf_get_image_sizes() {

    $image_sizes_orig = get_intermediate_image_sizes();

    $image_sizes_orig[] = 'full';

    $image_sizes = array();



    foreach ($image_sizes_orig as $size) {

        $image_sizes[$size] = $size;

    }



    return $image_sizes;

}



function wpuf_allowed_extensions() {

    $extesions = array(

        'images' => array('ext' => 'jpg,jpeg,gif,png,bmp', 'label' => __( 'Images', 'wpuf' )),

        'audio' => array('ext' => 'mp3,wav,ogg,wma,mka,m4a,ra,mid,midi', 'label' => __( 'Audio', 'wpuf' )),

        'video' => array('ext' => 'avi,divx,flv,mov,ogv,mkv,mp4,m4v,divx,mpg,mpeg,mpe', 'label' => __( 'Videos', 'wpuf' )),

        'pdf' => array('ext' => 'pdf', 'label' => __( 'PDF', 'wpuf' )),

        'office' => array('ext' => 'doc,ppt,pps,xls,mdb,docx,xlsx,pptx,odt,odp,ods,odg,odc,odb,odf,rtf,txt', 'label' => __( 'Office Documents', 'wpuf' )),

        'zip' => array('ext' => 'zip,gz,gzip,rar,7z', 'label' => __( 'Zip Archives' )),

        'exe' => array('ext' => 'exe', 'label' => __( 'Executable Files', 'wpuf' )),

        'csv' => array('ext' => 'csv', 'label' => __( 'CSV', 'wpuf' ))

    );



    return apply_filters( 'wpuf_allowed_extensions', $extesions );

}



/**

 * Adds notices on add post form if any

 *

 * @param string $text

 * @return string

 */

function wpuf_addpost_notice( $text ) {

    $user = wp_get_current_user();



    if ( is_user_logged_in() ) {

        $lock = ( $user->wpuf_postlock == 'yes' ) ? 'yes' : 'no';



        if ( $lock == 'yes' ) {

            return $user->wpuf_lock_cause;

        }

    }



    return $text;

}



add_filter( 'wpuf_addpost_notice', 'wpuf_addpost_notice' );



/**

 * Adds the filter to the add post form if the user can post or not

 *

 * @param string $perm permission type. "yes" or "no"

 * @return string permission type. "yes" or "no"

 */

function wpuf_can_post( $perm ) {

    $user = wp_get_current_user();



    if ( is_user_logged_in() ) {

        $lock = ( $user->wpuf_postlock == 'yes' ) ? 'yes' : 'no';



        if ( $lock == 'yes' ) {

            return 'no';

        }

    }



    return $perm;

}



add_filter( 'wpuf_can_post', 'wpuf_can_post' );



/**

 * Associate attachemnt to a post

 *

 * @since 2.0

 *

 * @param type $attachment_id

 * @param type $post_id

 */

function wpuf_associate_attachment( $attachment_id, $post_id ) {

    wp_update_post( array(

        'ID' => $attachment_id,

        'post_parent' => $post_id

    ) );

}



/**

 * Get user role names

 *

 * @since 2.0

 *

 * @global WP_Roles $wp_roles

 * @return array

 */

function wpuf_get_user_roles() {

    global $wp_roles;



    if ( !isset( $wp_roles ) )

        $wp_roles = new WP_Roles();



    return $wp_roles->get_names();

}



/**

 * User avatar wrapper for custom uploaded avatar

 *

 * @since 2.0

 *

 * @param string $avatar

 * @param mixed $id_or_email

 * @param int $size

 * @param string $default

 * @param string $alt

 * @return string image tag of the user avatar

 */

function wpuf_get_avatar( $avatar, $id_or_email, $size, $default, $alt ) {



    if ( is_numeric( $id_or_email ) ) {

        $user = get_user_by( 'id', $id_or_email );

    } elseif ( is_object( $id_or_email ) ) {

        if ( $id_or_email->user_id != '0' ) {

            $user = get_user_by( 'id', $id_or_email->user_id );

        } else {

            return $avatar;

        }

    } else {

        $user = get_user_by( 'email', $id_or_email );

    }



    // see if there is a user_avatar meta field

    $user_avatar = get_user_meta( $user->ID, 'user_avatar', true );

    if ( empty( $user_avatar ) ) {

        return $avatar;

    }



    return sprintf( '<img src="%1$s" alt="%2$s" height="%3$s" width="%3$s" class="avatar">', esc_url( $user_avatar ), $alt, $size );

}



add_filter( 'get_avatar', 'wpuf_get_avatar', 99, 5 );



function wpuf_update_avatar( $user_id, $attachment_id ) {



    $upload_dir = wp_upload_dir();

    $relative_url = wp_get_attachment_url( $attachment_id );



    if ( function_exists( 'wp_get_image_editor' ) ) {

        // try to crop the photo if it's big

        $file_path = str_replace( $upload_dir['baseurl'], $upload_dir['basedir'], $relative_url );



        // as the image upload process generated a bunch of images

        // try delete the intermediate sizes.

        $ext = strrchr( $file_path, '.' );

        $file_path_w_ext = str_replace( $ext, '', $file_path );

        $small_url = $file_path_w_ext . '-avatar' . $ext;

        $relative_url = str_replace( $upload_dir['basedir'], $upload_dir['baseurl'], $small_url );



        $editor = wp_get_image_editor( $file_path );



        if ( !is_wp_error( $editor ) ) {

            $editor->resize( 100, 100, true );

            $editor->save( $small_url );



            // if the file creation successfull, delete the original attachment

            if ( file_exists( $small_url ) ) {

                wp_delete_attachment( $attachment_id, true );

            }

        }

    }



    // delete any previous avatar

    $prev_avatar = get_user_meta( $user_id, 'user_avatar', true );



    if ( !empty( $prev_avatar ) ) {

        $prev_avatar_path = str_replace( $upload_dir['baseurl'], $upload_dir['basedir'], $prev_avatar );



        if ( file_exists( $prev_avatar_path ) ) {

            unlink( $prev_avatar_path );

        }

    }

    

    // now update new user avatar

    update_user_meta( $user_id, 'user_avatar', $relative_url );

}



function wpuf_admin_role() {

    return apply_filters( 'wpuf_admin_role', 'manage_options' );

}



/**

 * Get all the payment gateways

 *

 * @return array

 */

function wpuf_get_gateways( $context = 'admin' ) {

    $gateways = WPUF_Payment::get_payment_gateways();

    $return = array();



    foreach ($gateways as $id => $gate) {

        if ( $context == 'admin' ) {

            $return[$id] = $gate['admin_label'];

        } else {

            $return[$id] = array( 

                'label' => $gate['checkout_label'], 

                'icon' => isset( $gate['icon'] ) ? $gate['icon'] : ''

            );

        }

    }



    return $return;

}



/**

 * Show custom fields in post content area

 *

 * @global object $post

 * @param string $content

 * @return string

 */

function wpuf_show_custom_fields( $content ) {

    global $post;



    $show_custom = wpuf_get_option( 'cf_show_front', 'wpuf_general' );



    if ( $show_custom != 'on' ) {

        return $content;

    }



    $form_id = get_post_meta( $post->ID, '_wpuf_form_id', true );



    if ( !$form_id ) {

        return $content;

    }



    $html = '<ul class="wpuf_customs">';



    $form_vars = get_post_meta( $form_id, 'wpuf_form', true );

    $meta = array();



    if ( $form_vars ) {

        foreach ($form_vars as $attr) {

            if ( isset( $attr['is_meta'] ) && $attr['is_meta'] == 'yes' ) {

                $meta[] = $attr;

            }

        }



        if ( !$meta ) {

            return $content;

        }



        foreach ($meta as $attr) {

            $field_value = get_post_meta( $post->ID, $attr['name'] );

            

            if ( $attr['input_type'] == 'hidden' ) {

                continue;

            }



            if ( $attr['input_type'] == 'image_upload' || $attr['input_type'] == 'file_upload' ) {

                $image_html = '<li><label>' . $attr['label'] . ':</label> ';



                if ( $field_value ) {

                    foreach ($field_value as $attachment_id) {



                        if ( $attr['input_type'] == 'image_upload' ) {

                            $thumb = wp_get_attachment_image( $attachment_id, 'thumbnail' );

                        } else {

                            $thumb = get_post_field( 'post_title', $attachment_id );

                        }



                        $full_size = wp_get_attachment_url( $attachment_id );

                        $image_html .= sprintf( '<a href="%s">%s</a> ', $full_size, $thumb );

                    }

                }



                $html .= $image_html . '</li>';

                

            } elseif ( $attr['input_type'] == 'map' ) {

                ob_start();

                wpuf_shortcode_map_post($attr['name'], $post->ID);

                $html .= ob_get_clean();

            } else {



                $value = get_post_meta( $post->ID, $attr['name'] );

                $html .= sprintf( '<li><label>%s</label>: %s</li>', $attr['label'], make_clickable( implode( ', ', $value ) ) );

            }

        }

    }



    $html .= '</ul>';



    return $content . $html;

}



add_filter( 'the_content', 'wpuf_show_custom_fields' );



/**

 * Map display shortcode

 *

 * @param string $meta_key

 * @param int $post_id

 * @param array $args

 */

function wpuf_shortcode_map( $location, $post_id = null, $args = array(), $meta_key = '' ) {

    global $post;

    

    // compatibility

    if ( $post_id ) {

        wpuf_shortcode_map_post( $location, $post_id, $args );

        return;

    }



    $default = array('width' => 450, 'height' => 250, 'zoom' => 12);

    $args = wp_parse_args( $args, $default );



    list( $def_lat, $def_long ) = explode( ',', $location );

    $def_lat = $def_lat ? $def_lat : 0;

    $def_long = $def_long ? $def_long : 0;

    ?>



    <div class="google-map" style="margin: 10px 0; height: <?php echo $args['height']; ?>px; width: <?php echo $args['width']; ?>px;" id="wpuf-map-<?php echo $meta_key . $post->ID; ?>"></div>



    <script type="text/javascript">

        jQuery(function($){

            var curpoint = new google.maps.LatLng(<?php echo $def_lat; ?>, <?php echo $def_long; ?>);



            var gmap = new google.maps.Map( $('#wpuf-map-<?php echo $meta_key . $post->ID; ?>')[0], {

                center: curpoint,

                zoom: <?php echo $args['zoom']; ?>,

                mapTypeId: window.google.maps.MapTypeId.ROADMAP

            });



            var marker = new window.google.maps.Marker({

                position: curpoint,

                map: gmap,

                draggable: true

            });

            

        });

    </script>

    <?php

}



/**

 * Map shortcode for users

 * 

 * @param string $meta_key

 * @param int $user_id

 * @param array $args

 */

function wpuf_shortcode_map_user( $meta_key, $user_id = null, $args = array() ) {

    $location = get_user_meta( $user_id, $meta_key, true );

    wpuf_shortcode_map( $location, null, $args, $meta_key );

}



/**

 * Map shortcode post posts

 * 

 * @global object $post

 * @param string $meta_key

 * @param int $post_id

 * @param array $args

 */

function wpuf_shortcode_map_post( $meta_key, $post_id = null, $args = array() ) {

    global $post;

    

    if ( !$post_id ) {

        $post_id = $post->ID;

    }

    

    $location = get_post_meta( $post_id, $meta_key, true );

    wpuf_shortcode_map( $location, null, $args, $meta_key );

}



function wpuf_meta_shortcode( $atts ) {

    global $post;



    extract( shortcode_atts( array(

        'name' => '',

        'type' => 'normal',

        'size' => 'thumbnail',

        'height' => 250,

        'width' => 450,

        'zoom' => 12

    ), $atts ) );



    if ( empty( $name ) ) {

        return;

    }



    if ( $type == 'image' || $type == 'file' ) {

        $images = get_post_meta( $post->ID, $name );



        if ( $images ) {

            $html = '';

            foreach ($images as $attachment_id) {



                if ( $type == 'image' ) {

                    $thumb = wp_get_attachment_image( $attachment_id, $size );

                } else {

                    $thumb = get_post_field( 'post_title', $attachment_id );

                }



                $full_size = wp_get_attachment_url( $attachment_id );

                $html .= sprintf( '<a href="%s">%s</a> ', $full_size, $thumb );

            }



            return $html;

        }



    } elseif ( $type == 'map' ) {

        ob_start();

        wpuf_shortcode_map( $name, $post->ID, array('width' => $width, 'height' => $height, 'zoom' => $zoom ) );

        return ob_get_clean();



    } elseif ( $type == 'repeat' ) {

        return implode( '; ', get_post_meta( $post->ID, $name ) );

    } else {

        return implode( ', ', get_post_meta( $post->ID, $name ) );

    }

}



add_shortcode( 'wpuf-meta', 'wpuf_meta_shortcode' );





/**

 * Get the value of a settings field

 *

 * @param string $option settings field name

 * @param string $section the section name this field belongs to

 * @param string $default default text if it's not found

 * @return mixed

 */

function wpuf_get_option( $option, $section, $default = '' ) {



    $options = get_option( $section );



    if ( isset( $options[$option] ) ) {

        return $options[$option];

    }



    return $default;

}



/**

 * check the current post for the existence of a short code

 *

 * @link http://wp.tutsplus.com/articles/quick-tip-improving-shortcodes-with-the-has_shortcode-function/

 * @param string $shortcode

 * @return boolean

 */

function wpuf_has_shortcode( $shortcode = '', $post_id = false ) {

  

    $post_to_check = ( $post_id == false ) ? get_post( get_the_ID() ) : get_post( $post_id );

  

    if ( !$post_to_check ) {

        return false;

    }

  

    // false because we have to search through the post content first

    $found = false;

  

    // if no short code was provided, return false

    if ( !$shortcode ) {

        return $found;

    }

  

    // check the post content for the short code

    if ( stripos( $post_to_check->post_content, '[' . $shortcode ) !== false ) {

        // we have found the short code

        $found = true;

    }

  

    return $found;

}