<?php
/**
 * Twenty Twelve functions and definitions.
 *
 * Sets up the theme and provides some helper functions, which are used
 * in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook.
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package WordPress
 * @subpackage Twenty_Twelve
 * @since Twenty Twelve 1.0
 */
/**
 * Sets up the content width value based on the theme's design and stylesheet.
 */
if (!isset($content_width))
    $content_width = 625;

add_filter('show_admin_bar', '__return_false');

add_action('wp_head','pluginname_ajaxurl',1);
function pluginname_ajaxurl() {
    ?>
    <script type="text/javascript">
    var ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>';
    </script>
    <?php
}


/**
 * Sets up theme defaults and registers the various WordPress features that
 * Twenty Twelve supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add a Visual Editor stylesheet.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,
 * 	custom background, and post formats.
 * @uses register_nav_menu() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since Twenty Twelve 1.0
 */
/* define('MASTERYO', true);
  ini_set("session.gc_maxlifetime", "86400");
  session_start();
  $curr_session_id = session_id(); */
$current_user = wp_get_current_user();
$date = new DateTime();
if (is_user_logged_in()) {
    update_usermeta($current_user->ID, 'lastvisit', $date->getTimestamp());
}

function twentytwelve_setup() {
    /*
     * Makes Twenty Twelve available for translation.
     *
     * Translations can be added to the /languages/ directory.
     * If you're building a theme based on Twenty Twelve, use a find and replace
     * to change 'twentytwelve' to the name of your theme in all the template files.
     */
    load_theme_textdomain('twentytwelve', get_template_directory() . '/languages');

    // This theme styles the visual editor with editor-style.css to match the theme style.
    add_editor_style();

    // Adds RSS feed links to <head> for posts and comments.
    add_theme_support('automatic-feed-links');

    // This theme supports a variety of post formats.
    add_theme_support('post-formats', array('aside', 'image', 'link', 'quote', 'status'));

    // This theme uses wp_nav_menu() in one location.
    register_nav_menu('primary', __('Primary Menu', 'twentytwelve'));

    /*
     * This theme supports custom background color and image, and here
     * we also set up the default background color.
     */
    add_theme_support('custom-background', array(
        'default-color' => 'e6e6e6',
    ));

    // This theme uses a custom image size for featured images, displayed on "standard" posts.
    add_theme_support('post-thumbnails');
    set_post_thumbnail_size(624, 9999); // Unlimited height, soft crop
}

add_action('after_setup_theme', 'twentytwelve_setup');

/**
 * Adds support for a custom header image.
 */
require( get_template_directory() . '/inc/custom-header.php' );

/**
 * Returns the Google font stylesheet URL if available.
 *
 * The use of Open Sans by default is localized. For languages that use
 * characters not supported by the font, the font can be disabled.
 *
 * @since Twenty Twelve 1.2
 *
 * @return string Font stylesheet or empty string if disabled.
 */
function twentytwelve_get_font_url() {
    $font_url = '';

    /* translators: If there are characters in your language that are not supported
      by Open Sans, translate this to 'off'. Do not translate into your own language. */
    if ('off' !== _x('on', 'Open Sans font: on or off', 'twentytwelve')) {
        $subsets = 'latin,latin-ext';

        /* translators: To add an additional Open Sans character subset specific to your language, translate
          this to 'greek', 'cyrillic' or 'vietnamese'. Do not translate into your own language. */
        $subset = _x('no-subset', 'Open Sans font: add new subset (greek, cyrillic, vietnamese)', 'twentytwelve');

        if ('cyrillic' == $subset)
            $subsets .= ',cyrillic,cyrillic-ext';
        elseif ('greek' == $subset)
            $subsets .= ',greek,greek-ext';
        elseif ('vietnamese' == $subset)
            $subsets .= ',vietnamese';

        $protocol = is_ssl() ? 'https' : 'http';
        $query_args = array(
            'family' => 'Open+Sans:400italic,700italic,400,700',
            'subset' => $subsets,
        );
        $font_url = add_query_arg($query_args, "$protocol://fonts.googleapis.com/css");
    }

    return $font_url;
}

/**
 * Enqueues scripts and styles for front-end.
 *
 * @since Twenty Twelve 1.0
 */
function twentytwelve_scripts_styles() {
    global $wp_styles;

    /*
     * Adds JavaScript to pages with the comment form to support
     * sites with threaded comments (when in use).
     */
    if (is_singular() && comments_open() && get_option('thread_comments'))
        wp_enqueue_script('comment-reply');

    /*
     * Adds JavaScript for handling the navigation menu hide-and-show behavior.
     */
    wp_enqueue_script('twentytwelve-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true);

    $font_url = twentytwelve_get_font_url();
    if (!empty($font_url))
        wp_enqueue_style('twentytwelve-fonts', esc_url_raw($font_url), array(), null);

    /*
     * Loads our main stylesheet.
     */
    wp_enqueue_style('twentytwelve-style', get_stylesheet_uri());

    /*
     * Loads the Internet Explorer specific stylesheet.
     */
    wp_enqueue_style('twentytwelve-ie', get_template_directory_uri() . '/css/ie.css', array('twentytwelve-style'), '20121010');
    $wp_styles->add_data('twentytwelve-ie', 'conditional', 'lt IE 9');
}

add_action('wp_enqueue_scripts', 'twentytwelve_scripts_styles');

/**
 * Adds additional stylesheets to the TinyMCE editor if needed.
 *
 * @uses twentytwelve_get_font_url() To get the Google Font stylesheet URL.
 *
 * @since Twenty Twelve 1.2
 *
 * @param string $mce_css CSS path to load in TinyMCE.
 * @return string
 */
function twentytwelve_mce_css($mce_css) {
    $font_url = twentytwelve_get_font_url();

    if (empty($font_url))
        return $mce_css;

    if (!empty($mce_css))
        $mce_css .= ',';

    $mce_css .= esc_url_raw(str_replace(',', '%2C', $font_url));

    return $mce_css;
}

add_filter('mce_css', 'twentytwelve_mce_css');

/**
 * Creates a nicely formatted and more specific title element text
 * for output in head of document, based on current view.
 *
 * @since Twenty Twelve 1.0
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string Filtered title.
 */
function twentytwelve_wp_title($title, $sep) {
    global $paged, $page;

    if (is_feed())
        return $title;

    // Add the site name.
    $title .= get_bloginfo('name');

    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && ( is_home() || is_front_page() ))
        $title = "$title $sep $site_description";

    // Add a page number if necessary.
    if ($paged >= 2 || $page >= 2)
        $title = "$title $sep " . sprintf(__('Page %s', 'twentytwelve'), max($paged, $page));

    return $title;
}

add_filter('wp_title', 'twentytwelve_wp_title', 10, 2);

/**
 * Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
 *
 * @since Twenty Twelve 1.0
 */
function twentytwelve_page_menu_args($args) {
    if (!isset($args['show_home']))
        $args['show_home'] = true;
    return $args;
}

add_filter('wp_page_menu_args', 'twentytwelve_page_menu_args');

/**
 * Registers our main widget area and the front page widget areas.
 *
 * @since Twenty Twelve 1.0
 */
function twentytwelve_widgets_init() {
    register_sidebar(array(
        'name' => __('Main Sidebar', 'twentytwelve'),
        'id' => 'sidebar-1',
        'description' => __('Appears on posts and pages except the optional Front Page template, which has its own widgets', 'twentytwelve'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));

    register_sidebar(array(
        'name' => __('First Front Page Widget Area', 'twentytwelve'),
        'id' => 'sidebar-2',
        'description' => __('Appears when using the optional Front Page template with a page set as Static Front Page', 'twentytwelve'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));

    register_sidebar(array(
        'name' => __('Second Front Page Widget Area', 'twentytwelve'),
        'id' => 'sidebar-3',
        'description' => __('Appears when using the optional Front Page template with a page set as Static Front Page', 'twentytwelve'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));
}

add_action('widgets_init', 'twentytwelve_widgets_init');

if (!function_exists('twentytwelve_content_nav')) :

    /**
     * Displays navigation to next/previous pages when applicable.
     *
     * @since Twenty Twelve 1.0
     */
    function twentytwelve_content_nav($html_id) {
        global $wp_query;

        $html_id = esc_attr($html_id);

        if ($wp_query->max_num_pages > 1) :
            ?>
            <nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">
                <h3 class="assistive-text"><?php _e('Post navigation', 'twentytwelve'); ?></h3>
                <div class="nav-previous"><?php next_posts_link(__('<span class="meta-nav">&larr;</span> Older posts', 'twentytwelve')); ?></div>
                <div class="nav-next"><?php previous_posts_link(__('Newer posts <span class="meta-nav">&rarr;</span>', 'twentytwelve')); ?></div>
            </nav><!-- #<?php echo $html_id; ?> .navigation -->
            <?php
        endif;
    }

endif;

if (!function_exists('twentytwelve_comment')) :

    /**
     * Template for comments and pingbacks.
     *
     * To override this walker in a child theme without modifying the comments template
     * simply create your own twentytwelve_comment(), and that function will be used instead.
     *
     * Used as a callback by wp_list_comments() for displaying the comments.
     *
     * @since Twenty Twelve 1.0
     */
    function twentytwelve_comment($comment, $args, $depth) {
        $GLOBALS['comment'] = $comment;
        switch ($comment->comment_type) :
            case 'pingback' :
            case 'trackback' :
                // Display trackbacks differently than normal comments.
                ?>
                <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
                    <p><?php _e('Pingback:', 'twentytwelve'); ?> <?php comment_author_link(); ?> <?php edit_comment_link(__('(Edit)', 'twentytwelve'), '<span class="edit-link">', '</span>'); ?></p>
                    <?php
                    break;
                default :
                    // Proceed with normal comments.
                    global $post;
                    global $date;
                    global $current_user;
                    global $wpdb;
                    ?>
                <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
                    <article id="comment-<?php comment_ID(); ?>" class="comment">
                        <header class="comment-meta comment-author vcard">
                            <?php
                            echo get_avatar($comment, 44);
                            $lastuservisit = get_user_meta($comment->user_id, 'lastvisit', true);

                            if (is_user_logged_in() && $comment->user_id != 0) {
                                if ($date->getTimestamp() - $lastuservisit <= 50) {
                                    printf('<cite class="onlineicon"><b class="fn">%1$s</b> %2$s</cite>', get_comment_author_link(),
                                            // If current post author is also comment author, make it known visually.
                                            ( $comment->user_id === $post->post_author ) ? '<span>' . __('Post author', 'twentytwelve') . '</span>' : ''
                                    );
                                } else {
                                    printf('<cite class="offlineicon"><b class="fn">%1$s</b> %2$s</cite>', get_comment_author_link(),
                                            // If current post author is also comment author, make it known visually.
                                            ( $comment->user_id === $post->post_author ) ? '<span>' . __('Post author', 'twentytwelve') . '</span>' : ''
                                    );
                                }
                            } else {
                                printf('<cite><b class="fn">%1$s</b> %2$s</cite>', get_comment_author_link(),
                                        // If current post author is also comment author, make it known visually.
                                        ( $comment->user_id === $post->post_author ) ? '<span>' . __('Post author', 'twentytwelve') . '</span>' : ''
                                );
                            }
                            echo get_user_meta($comment->user_id, 'descrptn', true);

                            //$date->getTimestamp();


                            $check = $wpdb->query(
                                    $wpdb->prepare(
                                            "
                                select `r_id` from $wpdb->my_buddy
                                where (userid= %d and ref_userid= %d) or (userid= %d and ref_userid= %d)    
                                ", $current_user->ID, $comment->user_id, $comment->user_id, $current_user->ID
                                    )
                            );
                            $userlogin = get_userdata($comment->user_id)->user_login;
                            if ($check == 0 && $comment->user_id != 0 && is_user_logged_in() && $comment->user_id != $current_user->ID) {

                                echo "<a class='sendpm' href='" . get_bloginfo('url') . "/336-2/?dpm=folder&folder=5&receiver=" . $userlogin . "'>أرسل رسالة</a>";
                                ?>
                                <a class="addfriend addfriend<?php echo $comment->user_id ?>" id="<?php echo $comment->user_id ?>" href="" title="أضف صديق">أضف صديق</a>
                                <span class="requestadd<?php echo $comment->user_id ?>"></span>
                                <?php
                            }
                            printf('<a href="%1$s"><time datetime="%2$s">%3$s</time></a>', esc_url(get_comment_link($comment->comment_ID)), get_comment_time('c'),
                                    /* translators: 1: date, 2: time */ sprintf(__('%1$s at %2$s', 'twentytwelve'), get_comment_date(), get_comment_time())
                            );
                            ?>
                        </header><!-- .comment-meta -->

                        <?php if ('0' == $comment->comment_approved) : ?>
                            <p class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.', 'twentytwelve'); ?></p>
                        <?php endif; ?>

                        <section class="comment-content comment">
                            <?php comment_text(); ?>
                            <?php edit_comment_link(__('Edit', 'twentytwelve'), '<p class="edit-link">', '</p>'); ?>
                        </section><!-- .comment-content -->

                        <div class="reply">
                            <?php comment_reply_link(array_merge($args, array('reply_text' => __('Reply', 'twentytwelve'), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
                        </div><!-- .reply -->
                    </article><!-- #comment-## -->
                    <?php
                    break;
            endswitch; // end comment_type check
        }

    endif;

    if (!function_exists('twentytwelve_entry_meta')) :

        /**
         * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
         *
         * Create your own twentytwelve_entry_meta() to override in a child theme.
         *
         * @since Twenty Twelve 1.0
         */
        function twentytwelve_entry_meta() {
            /*      $categories_list = get_the_category_list(__(', ', 'twentytwelve'));
              global $current_user;

              global $wpdb;

              $tag_list = get_the_tag_list('', __(', ', 'twentytwelve'));

              $date = sprintf('<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>', esc_url(get_permalink()), esc_attr(get_the_time()), esc_attr(get_the_date('c')), esc_html(get_the_date())
              );

              $author = sprintf('<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>', esc_url(get_author_posts_url(get_the_author_meta('ID'))), esc_attr(sprintf(__('View all posts by %s', 'twentytwelve'), get_the_author())), get_the_author()
              );

              if ($tag_list) {
              $utility_text = __('This entry was posted in %1$s and tagged %2$s on %3$s<span class="by-author"> by %4$s</span>.', 'twentytwelve');
              } elseif ($categories_list) {
              $utility_text = __('This entry was posted in %1$s on %3$s<span class="by-author"> by %4$s</span>.', 'twentytwelve');
              } else {
              $utility_text = __('This entry was posted on %3$s<span class="by-author"> by %4$s</span>.', 'twentytwelve');
              }


              $nowdate = new DateTime();
              $authorid = get_the_author_ID();
              $lastuservisit = get_user_meta($authorid, 'lastvisit', true);
              $userdesc = " - " . get_user_meta($authorid, 'descrptn', true);

              $check = $wpdb->query(
              $wpdb->prepare(
              "
              select `r_id` from $wpdb->my_buddy
              where (userid= %d and ref_userid= %d) or (userid= %d and ref_userid= %d)
              ", $current_user->ID, $authorid, $authorid, $current_user->ID
              )
              );
              if ($check == 0 && $authorid != 0 && is_user_logged_in() && $authorid != $current_user->ID) {

              $addfr="<a class='addfriend addfriend".$authorid."' id='".$authorid."' href=''>أضف صديق</a>
              <span class='requestadd".$authorid."'></span>";


              }
              if ($nowdate->getTimestamp() - $lastuservisit <= 300)
              $useronoff = "- <label class='online'>متواجد</label";
              else
              $useronoff = "- <label class='offline'>غير متواجد</label>";

              echo "<div class='writtenby'><label>بواسطة: </label>$author" . " " .$addfr. " " .$userdesc . " " . $useronoff . "</div>";
              echo "<div class='date'>$date</div>"; */
        }

    endif;

    /**
     * Extends the default WordPress body class to denote:
     * 1. Using a full-width layout, when no active widgets in the sidebar
     *    or full-width template.
     * 2. Front Page template: thumbnail in use and number of sidebars for
     *    widget areas.
     * 3. White or empty background color to change the layout and spacing.
     * 4. Custom fonts enabled.
     * 5. Single or multiple authors.
     *
     * @since Twenty Twelve 1.0
     *
     * @param array Existing class values.
     * @return array Filtered class values.
     */
    function twentytwelve_body_class($classes) {
        $background_color = get_background_color();
        $background_image = get_background_image();

        if (!is_active_sidebar('sidebar-1') || is_page_template('page-templates/full-width.php'))
            $classes[] = 'full-width';

        if (is_page_template('page-templates/front-page.php')) {
            $classes[] = 'template-front-page';
            if (has_post_thumbnail())
                $classes[] = 'has-post-thumbnail';
            if (is_active_sidebar('sidebar-2') && is_active_sidebar('sidebar-3'))
                $classes[] = 'two-sidebars';
        }

        if (empty($background_image)) {
            if (empty($background_color))
                $classes[] = 'custom-background-empty';
            elseif (in_array($background_color, array('fff', 'ffffff')))
                $classes[] = 'custom-background-white';
        }

        // Enable custom font class only if the font CSS is queued to load.
        if (wp_style_is('twentytwelve-fonts', 'queue'))
            $classes[] = 'custom-font-enabled';

        if (!is_multi_author())
            $classes[] = 'single-author';

        return $classes;
    }

    add_filter('body_class', 'twentytwelve_body_class');

    /**
     * Adjusts content_width value for full-width and single image attachment
     * templates, and when there are no active widgets in the sidebar.
     *
     * @since Twenty Twelve 1.0
     */
    function twentytwelve_content_width() {
        if (is_page_template('page-templates/full-width.php') || is_attachment() || !is_active_sidebar('sidebar-1')) {
            global $content_width;
            $content_width = 960;
        }
    }

    add_action('template_redirect', 'twentytwelve_content_width');

    /**
     * Add postMessage support for site title and description for the Theme Customizer.
     *
     * @since Twenty Twelve 1.0
     *
     * @param WP_Customize_Manager $wp_customize Theme Customizer object.
     * @return void
     */
    function twentytwelve_customize_register($wp_customize) {
        $wp_customize->get_setting('blogname')->transport = 'postMessage';
        $wp_customize->get_setting('blogdescription')->transport = 'postMessage';
        $wp_customize->get_setting('header_textcolor')->transport = 'postMessage';
    }

    add_action('customize_register', 'twentytwelve_customize_register');

    /**
     * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
     *
     * @since Twenty Twelve 1.0
     */
    function twentytwelve_customize_preview_js() {
        wp_enqueue_script('twentytwelve-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array('customize-preview'), '20130301', true);
    }

    add_action('customize_preview_init', 'twentytwelve_customize_preview_js');

    /*     * ******************************************** */

    $path = get_stylesheet_directory_uri() . '/js/';
    wp_enqueue_script('login-box', $path . 'jquery.loginbox.js', array('jquery'));

    if (is_user_logged_in() && !is_admin()) {
        wp_enqueue_script('chat', $path . 'chat.js', array('jquery'));
        wp_enqueue_script('notifications', $path . 'notifications.js', array('jquery'));
    }

    function getnewsmarquee($atts) {

        extract(shortcode_atts(array(
            'catgid' => '1',
            'title' => 'title'
                        ), $atts));
        $query = new WP_Query('cat=' . $catgid . '&posts_per_page=7');

        if ($query->have_posts()) {
            while ($query->have_posts()) {
                $query->the_post();
                $newsTitle[] = get_the_title();
                $newsLinks[] = get_permalink();
            }

            $out = "<div class='news-bar'>
            <div class='mrqtit'>
                <h3>" . $title . "</h3>";

            $out.= '<marquee scrollamount="4" class="marque1" behavior="scroll" direction="right">';
            for ($i = 0; $i < count($newsTitle); $i++) {
                if ($i < (count($newsTitle)) - 1)
                    $out.="<a href='{$newsLinks[$i]}'>" . strip_tags($newsTitle[$i]) . " - </a> ";
                else
                    $out.="<a href='{$newsLinks[$i]}'>" . strip_tags($newsTitle[$i]) . "</a> ";
            }
            $out.="</marquee>               
            </div>
        </div>";
        }
        wp_reset_query();
        return $out;
    }

    add_shortcode('getnews', 'getnewsmarquee');
    /*     * ** login ** */

    function getlogindropdownbox() {
        // $out = '';
        if (is_user_logged_in()) {
            $out = "<div id='dashboard-side-nav' class='logged_in_user'>
                    <div class='avatar'>";

            $current_user = wp_get_current_user();

            //$out.=html_link(va_get_the_author_listings_url($current_user->ID, true), get_avatar($current_user->ID, 45));

            $out.="</div>
                    <div class='user_meta'>
                        <p>مرحبا <b>" . $current_user->display_name . "</b></p>
                        <p class='smaller'>عضو منذ " . mysql2date(get_option('date_format'), $current_user->user_registered) . "</p>
                    </div>
                    <ul class='userdb'>
                        <li><a href='#' id='notif-trigger'><span class='notification commentnotif'>&#x25BC;</span></a>
                        <ul id='notif-content'>";
            $out.="<img src='" . get_bloginfo('url') . "/wp-content/themes/twentytwelve/images/24-0.gif' class='aligncenter'> ";
            $out.="</ul>
                        </li>
                        <li><a href='" . get_bloginfo('url') . "?page_id=382'>مواضيعي</a></li>
                        <li><a href='" . get_bloginfo('url') . "?page_id=264'>العضوية</a></li>                 
                        <li><a href='" . get_bloginfo('url') . "?page_id=321'>قائمة الأصدقاء<span class='notification friendnotif'></span></a></li>
                        <li class='inboxpm'><a class='inboxlink' href='" . get_bloginfo('url') . "/?page_id=336'>الرسائل الخاصة<span class='notification inboxnotif'></span></a></li>           
                        <li><a href='" . get_bloginfo('url') . "/?page_id=340'>تعديل الملف الشخصى</a></li>";
            /*         if ($current_user->has_claimed) { 
              <li class="claimed-listings"><?php echo html_link(va_get_claimed_listings_url(), __('Claimed Listings', APP_TD)); ?></li>
              <?php } */
            $out.="<li class='logout'><a href='" . wp_logout_url(home_url()) . "'>تسجيل الخروج</a></li>        
                    </ul>
                    <div class='clear'></div>
                </div>";
        } else {
            $out = "<nav class='logindr'>
                    <ul>
                    <li id='signup'>
			<a href='" . get_bloginfo('url') . "?page_id=258'>سجل الآن!</a>
                    </li>
                    <li id='login'>
                        <a id='login-trigger' href='#'>
                        <span>▼</span> تسجيل الدخول
                        </a>
                        <div id='login-content'>
                        <form id='loginform' action='" . get_option('home') . "/wp-login.php' method='post'>
                        <label>اسم المستخدم:<input type='text' name='log' id='log' style='margin-right: 10px;height: 15px;' value='' size='25' tabindex='1' /></label>
                        <label>كلمة السر: <input type='password' name='pwd' style='margin-right: 35px;height: 15px;' id='pwd' value='' size'25' tabindex='2' /></label>
                        <a href='" . get_bloginfo('url') . "?page_id=258' style='color:#fff;'>
                        مستخدم جديد؟
                        </a> | 
                        <a href='" . get_bloginfo('url') . "?page_id=573' style='color:#fff;'>فقدت كلمة المرور؟</a>
                        <input type='submit' name='login' id='submit' value='دخول' tabindex='4' />";
            // set a redirect for after logging in
            if (isset($_REQUEST['redirect_to'])) {
                $redirect = $_REQUEST['redirect_to'];
            }

            if (!isset($redirect))
                $redirect = home_url();

            $out.="<input type='hidden' name='redirect_to' value='" . esc_attr($redirect) . "' />
        <input type='hidden' name='testcookie' value='1' />	

    </form>


</div>                     
</li>

</ul>
</nav>";
        }
        return $out;
    }

    add_shortcode('getloginbox', 'getlogindropdownbox');

    /*     * *****category dropdown sidebar************** */

    function getcategorydropdownbox() {
//wp_list_categories('orderby=name&title_li=&exclude=10');
        $out = "<nav class='cat'><ul class='catul'>";
        $categories = get_categories();
        foreach ($categories as $cat) {
            if ($cat->category_parent != 0) {
                echo '<span style="padding-left:10px;">';
            }
            //echo $cat->cat_ID;exit();
            $out.="<li class='catli'>
    <a class='cattrigger' href='#'>
<span>▼</span>" . $cat->cat_name . "
</a>";
            /*             * *** */

            $args = array('posts_per_page' => 5, 'offset' => 1, 'category' => 6);

            $myposts = get_posts($args);

            foreach ($myposts as $post) : setup_postdata($post);


                $out.="<div class='postcontent'><a href='" . get_permalink() . "'>" . get_the_title() . "</a>
</div>";


            /*             * *** */


            endforeach;
            wp_reset_postdata();
        }


        $out.=" </ul></nav>";

        return $out;
    }

    /*     * ***************** */
    add_shortcode('getcategorybox', 'getcategorydropdownbox');


    /*     * ***************** */

    function default_login_redirect($redirect, $request_redirect) {
        if ($request_redirect === '')
            $redirect = home_url();
        return $redirect;
    }

    add_filter('login_redirect', 'default_login_redirect', 10, 2);

    function html($tag) {
        $args = func_get_args();

        $tag = array_shift($args);

        if (is_array($args[0])) {
            $closing = $tag;
            $attributes = array_shift($args);
            foreach ($attributes as $key => $value) {
                if (false === $value)
                    continue;

                if (true === $value)
                    $value = $key;

                $tag .= ' ' . $key . '="' . esc_attr($value) . '"';
            }
        } else {
            list( $closing ) = explode(' ', $tag, 2);
        }

        if (in_array($closing, array('area', 'base', 'basefont', 'br', 'hr', 'input', 'img', 'link', 'meta'))) {
            return "<{$tag} />";
        }

        $content = implode('', $args);

        return "<{$tag}>{$content}</{$closing}>";
    }

// Generate an <a> tag
    if (!function_exists('html_link')):

        function html_link($url, $title = '') {
            if (empty($title))
                $title = $url;

            return html('a', array('href' => $url), $title);
        }

    endif;


    register_sidebar(array(
        'name' => __('Logo'),
        'id' => 'rslogo',
        'class' => 'rslogo',
        'description' => __(''),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '',
        'after_title' => '',
    ));

    register_sidebar(array(
        'name' => __('Archive'),
        'id' => 'parchive',
        'class' => 'parchive',
        'description' => __(''),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '',
        'after_title' => '',
    ));

    register_sidebar(array(
        'name' => __('Footer logo'),
        'id' => 'footerlogo',
        'class' => 'footerlogo',
        'description' => __(''),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '',
        'after_title' => '',
    ));

    register_sidebar(array(
        'name' => __('footertwo'),
        'id' => 'footertwo',
        'class' => 'footertwo',
        'description' => __(''),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '',
        'after_title' => '',
    ));

    register_sidebar(array(
        'name' => __('Follow us'),
        'id' => 'followus',
        'class' => 'followus',
        'description' => __(''),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));

    register_sidebar(array(
        'name' => __('End of content'),
        'id' => 'endcontent',
        'class' => 'endcontent',
        'description' => __(''),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));
    register_sidebar(array(
        'name' => __('Google ad'),
        'id' => 'googlead',
        'class' => 'googlead',
        'description' => __(''),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));
    register_sidebar(array(
        'name' => __('Last Google ad'),
        'id' => 'googleadlast',
        'class' => 'googleadlast',
        'description' => __(''),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));

//add_filter('https_ssl_verify', '__return_false');


    /*     * ** user meta **** */
    add_action('show_user_profile', 'my_show_extra_profile_fields');
    add_action('edit_user_profile', 'my_show_extra_profile_fields');

    function my_show_extra_profile_fields($user) {
        ?>

        <h3>معلومات اضافية</h3>

        <table class="form-table">

            <tr>
                <th><label for="descrptn">نبذة</label></th>

                <td>
                    <input type="text" name="descrptn" id="descrptn" value="<?php echo esc_attr(get_the_author_meta('descrptn', $user->ID)); ?>" class="regular-text" /><br />
                    <span class="description">ادخل نبذة عن العضو</span>
                </td>
            </tr>

        </table>
        <?php
    }

    add_action('personal_options_update', 'my_save_extra_profile_fields');
    add_action('edit_user_profile_update', 'my_save_extra_profile_fields');

    function my_save_extra_profile_fields($user_id) {

        if (!current_user_can('edit_user', $user_id))
            return false;

        /* Copy and paste this line for additional fields. Make sure to change 'twitter' to the field ID. */
        update_usermeta($user_id, 'descrptn', $_POST['descrptn']);
    }

    /*     * * metafield for users last visit **** */

    add_action('show_user_profile', 'lastvisit');
    add_action('edit_user_profile', 'lastvisit');

    function lastvisit($user) {
        ?>

        <h3></h3>

        <table class="form-table">

            <tr>
                <th><label for="lastvisit">الزيارة الأخيرة</label></th>

                <td>
                    <input type="text" name="lastvisit" id="lastvisit" value="<?php echo esc_attr(get_the_author_meta('lastvisit', $user->ID)); ?>" class="regular-text" /><br />
                    <span class="description">تاريخ آخر زيارة</span>
                </td>
            </tr>

        </table>
        <?php
    }

    add_action('personal_options_update', 'save_lastvisit');
    add_action('edit_user_profile_update', 'save_lastvisit');

    function save_lastvisit($user_id) {

        if (!current_user_can('edit_user', $user_id))
            return false;

        /* Copy and paste this line for additional fields. Make sure to change 'twitter' to the field ID. */
        update_usermeta($user_id, 'lastvisit', $_POST['lastvisit']);
    }

    /*     * **sitemap **** */

    function sitemapFunc() {
        //echo do_shortcode('[pagelist]');
        $categories = get_categories();
        foreach ($categories as $cat) {
            echo $cat->cat_name;
            echo do_shortcode('[catlist id=' . $cat->cat_ID . ']');
        }
    }

    add_shortcode('getsitemap', 'sitemapFunc');


    /*
      if(is_user_logged_in()){
      switch ($this->vars['param'][0]) {
      case 'get_friend':
      $f = $this->db->getAll("SELECT login FROM ! WHERE login like '%!%' limit 0,8", array($GLOBALS['_member'], $this->vars['param'][1]));
      if (count($f) > 0 && is_array($f)) {
      foreach ($f as $key => $value) {
      $friends[] = $value['login'];
      }
      json_response($friends);
      die();
      }
      break;


      case 'like_me':
      $userids = $this->db->getAll("SELECT userid FROM ! WHERE ref_userid = '!' AND act = 'F' and status = 'active'", array($GLOBALS['_marriage_buddy'], $_SESSION['member']['member_id']));
      if (count($userids) > 0 && is_array($userids)) {
      foreach ($userids as $i => $v) {
      $user_ids[] = "'" . intval($v['userid']) . "'";
      }
      $data = $this->db->getAll("SELECT * FROM ! WHERE member_id IN (" . join(',', $user_ids) . ")", array($GLOBALS['_members']));
      $this->modSmartyAssign('data', $data);
      }
      if ($this->vars['auto_scroll'] == 'true') {
      die($this->modSmartyFetch('advmatch.tpl', true));
      } elseif ($this->vars['ajax'] == 'true')
      die($this->modSmartyFetch('advmatch.tpl'));
      return $this->modSmartyFetch('advmatch.tpl');
      break;
      case 'banlist':
      return $this->buddyBanList();
      break;
      case 'list_users':
      $users = $this->db->getAll("SELECT login FROM ! WHERE login like '%!%' limit 0,10", array($GLOBALS['_members'], $this->vars['param'][1]));
      $u = array();
      if (count($users) > 0 && is_array($users)) {
      foreach ($users as $k => $v)
      $u[] = $v['login'];
      }
      json_response($u);
      die();
      break;
      case 'add':
      //check if it's exists
      $check = $this->db->getOne("SELECT userid FROM ! WHERE userid = ! AND ref_userid = !", array($GLOBALS['_marriage_buddy'], $_SESSION['member']['member_id'], $this->vars['param'][1]));
      if ($check > 0) {
      return $this->display_list("مضاف مسبقا !", "error");
      } else {
      $this->db->query("INSERT INTO ! (userid,act,ref_userid,act_date,status) VALUES (!,'F',!,!,'active')", array($GLOBALS['_marriage_buddy'], $_SESSION['member']['member_id'], $this->vars['param'][1], time()));
      return $this->display_list("تم القبول بنجاح", "success");
      }
      break;
      case 'add-by-login':
      //check if it's exists
      $id = $this->db->getOne("SELECT member_id FROM ! WHERE login = '!' AND member_id not in (!)", array($GLOBALS['_members'], $this->vars['param'][1], $_SESSION['member']['member_id']));
      if ($id > 0) {
      //check if it's exists
      $check = $this->db->getOne("SELECT userid FROM ! WHERE userid = ! AND ref_userid = !", array($GLOBALS['_marriage_buddy'], $_SESSION['member']['member_id'], $id));
      if ($check > 0) {
      return $this->display_list("مضاف مسبقا !", "error");
      } else {

      $this->db->query("INSERT INTO ! (userid,act,ref_userid,act_date,status) VALUES (!,'F',!,!,'active')", array($GLOBALS['_marriage_buddy'], $_SESSION['member']['member_id'], $id, time()));
      return $this->display_list("تم الأضافة بنجاح", "success");
      }
      } else {
      return $this->display_list("اسم الصديق الذي قمت بادخاله غير صحيح !", "error");
      }

      break;
      case 'delete':
      $this->db->query("DELETE FROM ! WHERE ref_userid = '!' AND act = 'F' and status = 'active' and userid = !", array($GLOBALS['_marriage_buddy'], $this->vars['param'][1], $_SESSION['member']['member_id']));
      return $this->display_list("تم الحذف بنجاح", "success");
      break;
      default:
      return display_list();
      break;
      }
      }
      function display_list($message = "", $return = "") {
      if ($return != '') {
      $this->modSmartyAssign('message', $message);
      $this->modSmartyAssign('return', $return);
      }
      $userids = $this->db->getAll("SELECT ref_userid FROM ! WHERE userid = '!' AND act = 'F' and status = 'active'", array($GLOBALS['_marriage_buddy'], $_SESSION['member']['member_id']));
      $accpet_me = $this->db->getAll("SELECT id ,userid FROM ! WHERE ref_userid = '!' AND act = 'F' and status = 'active'", array($GLOBALS['_marriage_buddy'], $_SESSION['member']['member_id']));

      if (count($accpet_me) > 0 && is_array($accpet_me)) {
      //get the status of acception
      foreach ($accpet_me as $ii => $vv) {
      $acc_me[] = $vv['userid'];
      }
      }

      // my friend's list
      if (count($userids) > 0 && is_array($userids)) {
      foreach ($userids as $i => $v) {
      $user_ids[] = "'" . intval($v['ref_userid']) . "'";
      $my_list[] = intval($v['ref_userid']);
      }
      $data = $this->db->getAll("SELECT * FROM ! WHERE member_id IN (" . join(',', $user_ids) . ")", array($GLOBALS['_members']));


      $list = array();

      foreach ($data as $key => $value) {
      $list[$key] = $value;
      if (in_array($value['member_id'], $acc_me)) {
      $list[$key]['friend_status'] = 'تم القبول';
      } else {
      $list[$key]['friend_status'] = 'قيد الانتظار';
      }
      }
      $this->modSmartyAssign('friends', $list);
      }

      //pending friends
      if (count($accpet_me) > 0 && is_array($accpet_me)) {
      if (count($my_list) > 0 && is_array($my_list)) {
      foreach ($accpet_me as $ii => $vv) {
      if (!in_array($vv['userid'], $my_list)) {
      $my_pending_list[] = $vv['userid'];
      }
      }
      } else {
      $my_pending_list = $acc_me;
      }
      if (count($my_pending_list) > 0 && is_array($my_pending_list)) {
      $my_pending_user = $this->db->getAll("SELECT * FROM ! WHERE member_id IN (" . join(',', $my_pending_list) . ")", array($GLOBALS['_members']));
      $this->modSmartyAssign('pending_friends', $my_pending_user);
      }
      }

      if ($this->vars['ajax'] == 'true' && $this->vars['auto_scroll'] == 'true')
      die($this->modSmartyFetch('friends.tpl', true));
      elseif ($this->vars['ajax'] == 'true')
      die($this->modSmartyFetch('friends.tpl'));
      return $this->modSmartyFetch('friends.tpl');
      } */

    add_action("wp_ajax_add_user", "add_friend");
    add_action("wp_ajax_nopriv_add_user", "my_must_login");

    function add_friend() {

        global $wpdb;
        $current_user = wp_get_current_user();
        $date = new DateTime();
        $alreadyfriends = $wpdb->query(
                $wpdb->prepare(
                        "
                    select `r_id` from $wpdb->my_buddy
                    where userid= %d and ref_userid= %d and status='active'    
                    ", $current_user->ID, $_POST['friend_id']
                )
        );
        if ($alreadyfriends == 0) {
            $check = $wpdb->query(
                    $wpdb->prepare(
                            "
          insert into $wpdb->my_buddy
          (`userid`,`ref_userid`,`act`,`act_date`) values (%d,%d,%s,%d)

          ", $current_user->ID, $_POST['friend_id'], 'P', $date->getTimestamp()
                    )
            );
        }

        echo $check;
    }

    function my_must_login() {
        echo "يجب تسجيل الدخول";
        die();
    }

    /*     * *** creating a table in the database */

    function create_my_buddy() {
        global $wpdb;

        //create the name of the table including the wordpress prefix (wp_ etc)
        $search_table = $wpdb->prefix . "my_buddy";
        //$wpdb->show_errors();
        //check if there are any tables of that name already
        if ($wpdb->get_var("show tables like '$search_table'") !== $search_table) {
            //create your sql
            $sql = "CREATE TABLE " . $search_table . " (
    r_id int(11) NOT NULL AUTO_INCREMENT,
    userid varchar(30) NOT NULL,
    ref_userid varchar(30) NOT NULL,
    act_date int(11) NOT NULL,
    act char(1) NOT NULL,
    status enum('active','deleted') NOT NULL DEFAULT 'active',
    PRIMARY KEY (r_id),
    UNIQUE (userid,ref_userid),
    key act(act),
    key act_userid (act,userid),
    key act_ref_userid (act,ref_userid));";
        }

        //include the wordpress db functions
        require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
        dbDelta($sql);

        //register the new table with the wpdb object
        if (!isset($wpdb->my_buddy)) {
            $wpdb->my_buddy = $search_table;
            //add the shortcut so you can use $wpdb->stats
            $wpdb->tables[] = str_replace($wpdb->prefix, '', $search_table);
        }
    }

//add to front and backend inits
    add_action('init', 'create_my_buddy');

    /*     * ************* friend list *************** */

    function friend_list() {
        $current_user = wp_get_current_user();

        global $wpdb;
        $query = "select `ref_userid`,`act` from $wpdb->my_buddy where status='active' and userid=" . $current_user->ID . " order by `act` desc ";
        $results = $wpdb->get_results($query);
        $count = count($results);
        $out = "<h2>قائمة الأصدقاء <label class='countalrf'>$count</label></h2>";
        $out.="<ul class='friendlist'>";
        foreach ($results as $result) {
            //$result->ref_userid;
            $userdata = get_userdata($result->ref_userid);

            if ($result->act == 'P') {
                $out.= "<li class='friend" . $result->ref_userid . "'><label class='frname'>" . $userdata->user_firstname . " " . $userdata->user_lastname . "</label>" .
                        "<a class='deleteaddrequest' href='' id='" . $result->ref_userid . "'> قيد الانتظار x</a>
                
                   </li>";
                $out.= "<span class='deleted" . $result->ref_userid . "' style='display:none'></span>";
            } else if ($result->act == 'F') {
                $out.= "<li class='friend" . $result->ref_userid . "'>" . $userdata->user_firstname . " " . $userdata->user_lastname .
                        "<a class='deletefriend' href='' id='" . $result->ref_userid . "'> احذف </a>" .
                        "</li>";
                $out.= "<span class='deleted" . $result->ref_userid . "' style='display:none'></span>";
            }
        }
        $out.= "</ul>";


        return $out;
    }

    add_shortcode('friendlist', 'friend_list');

    function friend_request() {
        global $current_user;

        global $wpdb;
        $query = "select `userid` from $wpdb->my_buddy where status='active' and act='P' and ref_userid=" . $current_user->ID;
        $results = $wpdb->get_results($query);
        $count = count($results);
        $out = "";
        if ($count != 0) {
            $out = "<h2>لديك <label class='countfr'>" . $count . "</label> طلب إضافة</h2>";
            $out.="<ul class='waitinglist'>";
            foreach ($results as $result) {



                $userdata = get_userdata($result->userid);


                $out.="<li class='friend" . $result->userid . "'>" . $userdata->user_firstname . " " . $userdata->user_lastname .
                        "<a class='acceptfriend' href='' id='" . $result->userid . "'> موافقة</a>
                   <a class='declinefriend' href='' id='" . $result->userid . "'>رفض</a>
                   </li>";
                $out.= "<span class='respond" . $result->userid . "' style='display:none'></span>";
            }
            $out.= "</ul>";
        }
        return $out;
    }

    add_shortcode('friendrequests', 'friend_request');


    /*     * ***** deleting friend ********* */

    add_action("wp_ajax_delete_user", "delete_friend");
    add_action("wp_ajax_nopriv_delete_user", "my_must_loginn");

    function delete_friend() {

        global $wpdb;
        global $current_user;

        $check = $wpdb->query(
                $wpdb->prepare(
                        "
                    delete from $wpdb->my_buddy
                    where (userid= %d and ref_userid= %d) or (userid= %d and ref_userid= %d)    
                    ", $current_user->ID, $_POST['friend_id'], $_POST['friend_id'], $current_user->ID
                )
        );
        echo $check;
    }

    function my_must_loginn() {
        echo "يجب تسجيل الدخول";
        die();
    }

    /*     * ***********delete sent friend request********* */

    add_action("wp_ajax_delete_addrequest", "delete_addrequest");
    add_action("wp_ajax_nopriv_delete_addrequest", "my_must_deleteaddlogin");

    function delete_addrequest() {

        global $wpdb;
        global $current_user;

        $check = $wpdb->query(
                $wpdb->prepare(
                        "
                    delete from $wpdb->my_buddy 
                    where userid= %d and ref_userid= %d and act='P'    
                    ", $current_user->ID, $_POST['friend_id']
                )
        );
        echo $check;
    }

    function my_must_deleteaddloginn() {
        echo "يجب تسجيل الدخول";
        die();
    }

    /*     * * accept friend request** */
    add_action("wp_ajax_accept_friend", "accept_friend");
    add_action("wp_ajax_nopriv_accept_friend", "my_must_acceptlogin");

    function accept_friend() {

        global $wpdb;
        global $current_user;
        $date = new DateTime();

        $check1 = $wpdb->query(
                $wpdb->prepare(
                        "
          insert into $wpdb->my_buddy
          (`userid`,`ref_userid`,`act`,`act_date`) values (%d,%d,%s,%d)

          ", $current_user->ID, $_POST['friend_id'], 'F', $date->getTimestamp()
                )
        );

        $check2 = $wpdb->query(
                $wpdb->prepare(
                        "
          update $wpdb->my_buddy
          set act='F',act_date=%d where userid=%d and ref_userid=%d

          ", $date->getTimestamp(), $_POST['friend_id'], $current_user->ID
                )
        );


        echo $check1 . $check2;
    }

    function my_must_acceptlogin() {
        echo "يجب تسجيل الدخول";
        die();
    }

    /*     * **decline friend request ** */


    add_action("wp_ajax_decline_friend", "decline_friend");
    add_action("wp_ajax_nopriv_decline_friend", "my_must_declinelogin");

    function decline_friend() {

        global $wpdb;
        $current_user = wp_get_current_user();


        $check = $wpdb->query(
                $wpdb->prepare(
                        "
          delete from $wpdb->my_buddy
          where ref_userid=%d and userid=%d
       

          ", $current_user->ID, $_POST['friend_id']
                )
        );

        echo $check;
    }

    function my_must_declinelogin() {
        echo "يجب تسجيل الدخول";
        die();
    }

    function chat_friends() {

        $current_user = wp_get_current_user();
        global $wpdb;
        $query = "select `ref_userid` from $wpdb->my_buddy where status='active' and userid=" . $current_user->ID;
        $results = $wpdb->get_results($query);
        $count = count($results);
        $out = "<h2>المحادثة</h2>";
        $out.="<ul class='chatlist'>";
        foreach ($results as $result) {
            $userdata = get_userdata($result->ref_userid);
            $out.= "<li class='chat" . $result->ref_userid . "'>" . $userdata->user_firstname . " " . $userdata->user_lastname;
        }
        $out.= "</ul>";

        return $out;
    }

    add_shortcode('getchatfriends', 'chat_friends');
    /*     * ***chatting **** */

    /*     * creating the chatting table in db * */

    function create_chat() {
        global $wpdb;

        //create the name of the table including the wordpress prefix (wp_ etc)
        $search_table = $wpdb->prefix . "chat";
        //$wpdb->show_errors();
        //check if there are any tables of that name already
        if ($wpdb->get_var("show tables like '$search_table'") !== $search_table) {
            //create your sql
            $sql = "CREATE TABLE " . $search_table . " (
            c_id int(10) unsigned NOT NULL AUTO_INCREMENT,
            sfrom varchar(255) COLLATE utf8_unicode_ci NOT NULL,
            rto varchar(255) COLLATE utf8_unicode_ci NOT NULL,      
            sent datetime DEFAULT '0000-00-00 00:00:00',
            message text COLLATE utf8_unicode_ci NOT NULL,
            recd int(10) unsigned NOT NULL DEFAULT '0',
            PRIMARY KEY (c_id));";
        }

        //include the wordpress db functions
        require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
        dbDelta($sql);

        //register the new table with the wpdb object
        if (!isset($wpdb->chat)) {
            $wpdb->chat = $search_table;
            //add the shortcut so you can use $wpdb->stats
            $wpdb->tables[] = str_replace($wpdb->prefix, '', $search_table);
        }
    }

    add_action('init', 'create_chat');

    function chatBoxSession($chatbox) {

        $items = '';

        if (isset($_SESSION['chatHistory'][$chatbox])) {
            $items = $_SESSION['chatHistory'][$chatbox];
        }

        return $items;
    }

    function custom_notice() {

        global $db, $dbPrefix;
        global $wpdb;
        global $current_user;

        $count = $wpdb->query(
                $wpdb->prepare(
                        "
                    select `ref_userid`,`act` from $wpdb->my_buddy
                    where userid= %d and status='active'    
                    ", $current_user->ID
                )
        );

        $query = "select `ref_userid`,`act` from $wpdb->my_buddy where status='active' and userid=" . $current_user->ID;
        $my_list = $wpdb->get_results($query);
        if (count($my_list) > 0 && is_array($my_list)) {
            foreach ($my_list as $mylist) {

                $status = 'pending';
                $userdata = get_userdata($mylist->ref_userid);
                $login = $userdata->user_login;
                //$login = $db->getOne("SELECT login FROM ! WHERE member_id = '!'", array($dbPrefix . '_members', $v['ref_userid']));
                //foreach ($like_me as $ii => $vv) {
                if ($mylist->act == 'F')
                    $status = 'accepted';
                $current_user = wp_get_current_user();
                $date = new DateTime();
                update_usermeta($current_user->ID, 'lastvisit', $date->getTimestamp());
                $online_now = get_user_meta($mylist->ref_userid, 'lastvisit', true);
                if ($date->getTimestamp() - $online_now <= 50)
                    $online = 'Y';
                else
                    $online = 'N';
                $lists[] = '{"login" : "' . $login . '","status": "' . $status . '","online" :"' . $online . '"}';
            }
        } else {
            $lists[] = '{"list" : "none"}';
        }
        return array('lists' => $lists, 'count' => $count);
    }

    if (is_user_logged_in()) {
        add_action("wp_ajax_startchatsession", "startchatsession");
        add_action("wp_ajax_chatheartbeat", "chatheartbeat");
        add_action("wp_ajax_sendchat", "sendchat");
        add_action("wp_ajax_closechat", "closechat");
    }

    function startChatSession() {
        $current_user = wp_get_current_user();
        $items = '';


        if (!empty($_SESSION['openChatBoxes'])) {
            foreach ($_SESSION['openChatBoxes'] as $chatbox => $void) {
                $items .= chatBoxSession($chatbox);
            }
        }


        if ($items != '') {
            $items = substr($items, 0, -1);
        }
        $cn = custom_notice();
        header('Content-type: application/json');
        ?>
        {
        "username": "<?php echo $current_user->user_login; ?>",
        "items": [<?php echo $items; ?>],
        "lists": [<?php echo join(',', $cn['lists']); ?>],
        "count":[<?php echo $cn['count']; ?>]
        }

        <?php
        exit(0);
    }

    function chatheartbeat() {
        global $current_user;
        global $wpdb;
        $sql = "select * from $wpdb->chat where rto = '" . mysql_real_escape_string($current_user->user_login) . "' AND recd = 0 order by c_id ASC";
        $query = $wpdb->get_results($sql);

        $items = '';

        $chatBoxes = array();

        foreach ($query as $chat) {

            if (!isset($_SESSION['openChatBoxes'][$chat->sfrom]) && isset($_SESSION['chatHistory'][$chat->sfrom])) {
                $items = $_SESSION['chatHistory'][$chat->sfrom];
            }


            $items .= <<<EOD
					   {
			"s": "0",
			"f": "{$chat->sfrom}",
			"m": "{$chat->message}"
	   },
EOD;

            if (!isset($_SESSION['chatHistory'][$chat->sfrom])) {
                $_SESSION['chatHistory'][$chat->sfrom] = '';
            }

            $_SESSION['chatHistory'][$chat->sfrom] .= <<<EOD
						   {
			"s": "0",
			"f": "{$chat->sfrom}",
			"m": "{$chat->message}"
	   },
EOD;

            unset($_SESSION['tsChatBoxes'][$chat->sfrom]);
            $_SESSION['openChatBoxes'][$chat->sfrom] = $chat->sent;
        }

        if (!empty($_SESSION['openChatBoxes'])) {
            foreach ($_SESSION['openChatBoxes'] as $chatbox => $time) {
                if (!isset($_SESSION['tsChatBoxes'][$chatbox])) {
                    $now = time() - strtotime($time);
                    $time = date('g:iA M dS', strtotime($time));

                    $message = "Sent at $time";
                    if ($now > 180) {
                        $items .= <<<EOD
{
"s": "2",
"f": "$chatbox",
"m": "{$message}"
},
EOD;

                        if (!isset($_SESSION['chatHistory'][$chatbox])) {
                            $_SESSION['chatHistory'][$chatbox] = '';
                        }

                        $_SESSION['chatHistory'][$chatbox] .= <<<EOD
		{
"s": "2",
"f": "$chatbox",
"m": "{$message}"
},
EOD;
                        $_SESSION['tsChatBoxes'][$chatbox] = 1;
                    }
                }
            }
        }

        //$sql2 = "update $wpdb->chat set recd = 1 where rto = 'sarah' and recd = 0";
        //" . mysql_real_escape_string($current_user->user_login) . "
        //$query2 = mysql_query($sql2);

        $wpdb->query(
                $wpdb->prepare(
                        "
         update $wpdb->chat set recd=1
         where rto=%s and recd=0
         ", mysql_real_escape_string($current_user->user_login)
                )
        );


        if ($items != '') {
            $items = substr($items, 0, -1);
        }

        header('Content-type: application/json');
        $cn = custom_notice();
        ?>
        {

        "items": [<?php echo $items; ?>],
        "lists": [<?php echo join(',', $cn['lists']); ?>]
        }

        <?php
        exit(0);
    }

    function sendchat() {
        global $current_user;
        global $wpdb;
        //$from = $_SESSION['username'];
        $from = $current_user->user_login;
        $to = $_POST['to'];
        $message = $_POST['message'];

        $_SESSION['openChatBoxes'][$_POST['to']] = date('Y-m-d H:i:s', time());

        //$messagesan = sanitize($message);
        $messagesan = $message;

        if (!isset($_SESSION['chatHistory'][$_POST['to']])) {
            $_SESSION['chatHistory'][$_POST['to']] = '';
        }

        $_SESSION['chatHistory'][$_POST['to']] .= <<<EOD
					   {
			"s": "1",
			"f": "{$to}",
			"m": "{$messagesan}"
	   },
EOD;


        unset($_SESSION['tsChatBoxes'][$_POST['to']]);

        //$sql = "insert into chat (chat.sfrom,chat.rto,message,sent) values ('" . mysql_real_escape_string($from) . "', '" . mysql_real_escape_string($to) . "','" . mysql_real_escape_string($message) . "',NOW())";
        // $query = mysql_query($sql);


        $wpdb->query(
                $wpdb->prepare(
                        "
                        insert into $wpdb->chat (sfrom,rto,message,sent)
                        values (%s,%s,%s,%s)
          ", mysql_real_escape_string($from), mysql_real_escape_string($to), mysql_real_escape_string($message), date("Y-m-d H:i:s")
                )
        );


        echo "1";
        //echo NOW();
        //exit(0);
    }

    function closechat() {

        unset($_SESSION['openChatBoxes'][$_POST['chatbox']]);

        echo "1";
        exit(0);
    }

    /*     * *** the ads **** */

    function selectad() {
        $out = "<h2>أضف إعلان</h2>";
        $out.= "<select class='addiv' id='selectad'><option value='0'>اختر إعلان</option><option value='teacher'>اعلان مدرس</option><option value='school'>اعلان مدارس/معاهد</option></select>";

        $out.="<div class='retform'></div>";
        return $out;
    }

    add_shortcode('getadoptions', 'selectad');

    add_action("wp_ajax_getaddform", "getaddform");
    add_action("wp_ajax_nopriv_getaddform", "getaddformlogin");

    function getaddform() {
        if ($_POST['val'] == 'teacher')
            echo do_shortcode('[wpuf_form id="260"]');
        else if ($_POST['val'] == 'school')
            echo do_shortcode('[wpuf_form id="333"]');
    }

    function getaddformlogin() {
        echo "يجب تسجيل الدخول";
        die();
    }

    /*     * *** statistics *** */

    function sitestatistics($atts) {

        extract(shortcode_atts(array(
            'topics' => 'yes',
            'comments' => 'yes',
            'users' => 'yes',
            'supervisors' => 'yes',
                        ), $atts));
        $out = "<div class='statisticscontainer'>";
        if ($topics == 'yes') {
            $out.="<div class='statistics'><label>عدد المواضيع: </label>";
            $out.= wp_count_posts()->publish;
            $out.="</div>";
        }
        if ($comments == 'yes') {
            $out.="<div class='statistics'><label>عدد المشاركات: </label>";
            $out.=wp_count_comments()->approved;
            $out.="</div>";
        }
        if ($users == 'yes') {
            $out.="<div class='statistics'><label>عدد الأعضاء: </label>";
            $users = count_users();
            $out.=$users['total_users'];
            $out.="</div>";
        }
        if ($supervisors == 'yes') {
            $out.="<div class='statistics'><label>عدد المراقبين: </label>";
            $users = count_users();
            $out.=$users['avail_roles']['editor'];
            $out.="</div>";
        }
        $out.="</div>";
        return $out;
    }

    add_shortcode('getstatistics', 'sitestatistics');

    function myarchive() {
        return get_sidebar('archive');
    }

    add_shortcode('getarchive', 'myarchive');

    /*     * *********redirect if login failed********** */
    add_action('wp_login_failed', 'pippin_login_fail');  // hook failed login

    function pippin_login_fail($username) {
        $referrer = $_SERVER['HTTP_REFERER'];
        if (!empty($referrer) && !strstr($referrer, 'wp-login') && !strstr($referrer, 'wp-admin')) {
            wp_redirect(home_url() . '/?page_id=414');
            exit;
        }
    }

    /*     * *** comment checkbox in postmeta*** */

    add_action("admin_init", "checkbox_init");

    function checkbox_init() {
        add_meta_box("checkbox", "عرض التعليقات", "checkbox", "post", "normal", "high");
    }

    function checkbox() {
        global $post;
        $custom = get_post_custom($post->ID);
        $field_id = $custom["field_id"][0];
        ?>

        <label>عرض التعليقات: </label>
        <?php
        $field_id_value = get_post_meta($post->ID, 'field_id', true);
        if ($field_id_value == "yes")
            $field_id_checked = 'checked="checked"';
        ?>
        <input type="checkbox" name="field_id" value="yes" <?php echo $field_id_checked; ?> />
        <?php
    }

// Save Meta Details
    add_action('save_post', 'save_details');

    function save_details() {
        global $post;

        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return $post->ID;
        }

        update_post_meta($post->ID, "field_id", $_POST["field_id"]);
    }

    /*     * ************* */

    function truncate($string, $length = 80, $etc = '...', $break_words = false, $middle = false) {
        if ($length == 0)
            return '';

        if (strlen($string) > $length) {
            $length -= min($length, strlen($etc));
            if (!$break_words && !$middle) {
                $string = preg_replace('/\s+?(\S+)?$/', '', substr($string, 0, $length + 1));
            }
            if (!$middle) {
                return substr($string, 0, $length) . $etc;
            } else {
                return substr($string, 0, $length / 2) . $etc . substr($string, -$length / 2);
            }
        } else {
            return $string;
        }
    }

    add_action("wp_ajax_inboxnotification", "inboxnotification");

    function inboxnotification() {
        global $wpdb, $current_user;
        $user = $current_user->ID;
        /*         * * unseen messages ** */
        $pms = $wpdb->get_results("SELECT pm_id,pm_recipients FROM wp_a122_dexs_pmsystem where pm_read=0");
        $countinbox = 0;
        foreach ($pms AS $pm) {
            $recipients = unserialize($pm->pm_recipients);
            if (array_key_exists($user, $recipients))
                $countinbox++;
        }
        /*         * * friend requests ** */
        $query = "select `userid` from $wpdb->my_buddy where status='active' and act='P' and ref_userid=" . $current_user->ID;
        $results = $wpdb->get_results($query);
        $countfriends = count($results);

        /*         * * user post comments ** */
        $commentquery = "   select c.comment_ID from $wpdb->posts as p inner join $wpdb->comments as c inner join $wpdb->commentmeta as m where c.comment_ID=m.comment_id and m.meta_key='comment_seen' and m.meta_value='no' and c.comment_approved=1 and p.post_author=" . $current_user->ID . " and p.ID=c.comment_post_ID";
        $commentresults = $wpdb->get_results($commentquery);
        $countcomments = count($commentresults);
        echo $countinbox . '-' . $countfriends . '-' . $countcomments;
    }

    add_action("wp_ajax_inboxseen", "inboxseen");

    function inboxseen() {
        global $wpdb;
        $wpdb->query(
                $wpdb->prepare(
                        "update wp_a122_dexs_pmsystem set pm_read=1 where pm_id=%d", $_POST['msgid']
                )
        );
    }

    /*     * * comments noifications ** */
    add_action("wp_ajax_commentnotification", "commentnotification");

    function commentnotification() {
        global $wpdb, $current_user;

        /*         * * user post comments ** */
        $commentquery = "select c.comment_author,count(c.comment_ID) as commentsno,p.post_title,p.ID from $wpdb->comments as c inner join $wpdb->posts as p where c.comment_post_ID=p.ID and c.comment_approved=1 and p.post_author=" . $current_user->ID . " group by p.ID order by comment_date desc limit 6";
        $commentresults = $wpdb->get_results($commentquery);
        if ($commentresults == 0)
            echo "<li class='zeronotif'>ليس لديك اى اشعارات حتى الآن</li>";
        else {
            foreach ($commentresults as $comment) {
                $commentcount = $comment->commentsno - 1;
                $post_title = truncate($comment->post_title, 20);
                if ($commentcount == 1)
                    $others = 'آخر ';
                else
                    $others = 'آخرين ';
                if ($commentcount != 0)
                    echo "<li class='commentmetanotification' id='" . $comment->ID . "'><a href='" . get_bloginfo('url') . "?page_id=" . $comment->ID . "'>قام " . $comment->comment_author . " و " . $commentcount . ' ' . $others . "  بالتعليق على موضوعك: " . '"' . $post_title . '"' . "</a></li>";
                else
                    echo "<li class='commentmetanotification' id='" . $comment->ID . "'><a href='" . get_bloginfo('url') . "?page_id=" . $comment->ID . "'>قام " . $comment->comment_author . "  بالتعليق على موضوعك: " . '"' . $post_title . '"' . "</a></li>";
            }
            echo "<li class='seeAll'><a href='" . get_bloginfo('url') . "?page_id=532'>جميع الاشعارات</a></li>";
        }
        $wpdb->query(
                $wpdb->prepare(
                        "update $wpdb->commentmeta set meta_value= %s where meta_key= %s" , 'yes' , 'comment_seen'
                )
        );
    }

    function add_custom_comment_field($comment_id) {
        add_comment_meta($comment_id, 'comment_seen', 'no');
    }

    add_action('comment_post', 'add_custom_comment_field');

    function all_notifications() {
        global $current_user, $wpdb;
        $commentquery = "select c.comment_author,count(c.comment_ID) as commentsno,p.post_title,p.ID from $wpdb->comments as c inner join $wpdb->posts as p where c.comment_post_ID=p.ID and c.comment_approved=1 and p.post_author=" . $current_user->ID . " group by p.ID order by comment_date desc";
        $commentresults = $wpdb->get_results($commentquery);
        if ($commentresults == 0)
            $out = "<li class='zeronotif'>ليس لديك اى اشعارات حتى الآن</li>";
        else {
            $out = '';
            foreach ($commentresults as $comment) {
                $commentcount = $comment->commentsno - 1;
                if ($commentcount == 1)
                    $others = 'آخر ';
                else
                    $others = 'آخرين ';
                if ($commentcount != 0)
                    $out.="<li class='commentmetanotification' id='" . $comment->ID . "'><a href='" . get_bloginfo('url') . "?page_id=" . $comment->ID . "'>قام " . $comment->comment_author . " و " . $commentcount . ' ' . $others . "  بالتعليق على موضوعك: " . $comment->post_title . "</a></li>";
                else
                    $out.="<li class='commentmetanotification' id='" . $comment->ID . "'><a href='" . get_bloginfo('url') . "?page_id=" . $comment->ID . "'>قام " . $comment->comment_author . "  بالتعليق على موضوعك: " . $comment->post_title . "</a></li>";
            }
        }
        return $out;
    }

    add_shortcode('getallnotifications', 'all_notifications');

    /*     * **  general option for adding topics or ads  *** */

    function eg_settings_api_membershipinit() {

        add_settings_section('eg_setting_section', 'العضوية الذهبية', 'eg_setting_section_callback_function', 'general');

        add_settings_field('eg_setting_name', '', 'eg_setting_callback_function', 'general', 'eg_setting_section');

        register_setting('general', 'eg_setting_name');
    }

    add_action('admin_init', 'eg_settings_api_membershipinit');

    function eg_setting_section_callback_function() {
        echo '<p>جعل اضافة مواضيع فى قسمى المعلمين و المدارس برسوم</p>';
    }

    function eg_setting_callback_function() {
        echo '<input name="eg_setting_name" id="gv_thumbnails_insert_into_excerpt" type="checkbox" value="1" class="code" ' . checked(1, get_option('eg_setting_name'), false) . ' /> تفعيل العضوية للاعلانات';
    }

    /*     * *** adding general option for showing or hiding comments */

    function eg_settings_api_commentsinit() {

        add_settings_section('eg_setting_commentsection', 'اخفاء /اظهار التعليقات', 'eg_setting_section_commentcallback_function', 'discussion');

        add_settings_field('eg_setting_commentname', '', 'eg_setting_commentcallback_function', 'discussion', 'eg_setting_commentsection');

        register_setting('discussion', 'eg_setting_commentname');
    }

    add_action('admin_init', 'eg_settings_api_commentsinit');

    function eg_setting_section_commentcallback_function() {
        echo '';
    }

    function eg_setting_commentcallback_function() {
        echo '<input name="eg_setting_commentname" id="gv_thumbnails_insert_into_excerpt" type="checkbox" value="1" class="code" ' . checked(1, get_option('eg_setting_commentname'), false) . ' />اخفاء جميع التعليقات ';
    }
